<?php

namespace Drupal\node_link_report\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class NodeLinkReportAdminForm.
 */
class NodeLinkReportAdminForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'node_link_report_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('node_link_report.settings');

    $form['enable_check_external_links'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable checking and reporting of external links'),
      '#description' => $this->t(
        'When enabled, the block will report on external links as well as internal links.'
      ),
      '#weight' => '0',
      '#default_value' => $config->get('enable_check_external_links'),
    ];

    $form['enable_reporting_good_links'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable reporting of good links'),
      '#description' => $this->t(
        'When enabled, the block will report good links as well as bad. Useful for seeing all links on the page.'
      ),
      '#weight' => '0',
      '#default_value' => $config->get('enable_reporting_good_links'),
    ];

    $defaults_display_on = [];
    if ($config->get('display_on_node_edit')) {
      $defaults_display_on[] = 'node_edit';
    }
    if ($config->get('display_on_node_view')) {
      $defaults_display_on[] = 'node_view';
    }
    if ($config->get('display_on_node_preview')) {
      $defaults_display_on[] = 'node_preview';
    }
    $form['allow_display_on'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('What pages should be able to display the link report block:'),
      '#description' => $this->t(
        'Regardless of these settings, the block will still need to placed in your desired region in the block admin (/admin/structure/block).'
      ),
      '#options' => [
        'node_view' => $this->t('Node View'),
        'node_edit' => $this->t('Node Edit'),
        'node_preview' => $this->t('Node Preview'),

      ],
      '#weight' => '5',
      '#default_value' => $defaults_display_on,
    ];

    $form['additional_domains_as_internal'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Additional domains to treat as internal.'),
      '#description' => $this->t(
        'If your site has multiple domains, add domains, one per line that can be treated as internal links.'
      ). ' (www.example.com)',
      '#weight' => '10',
      '#default_value' => $config->get('additional_domains_as_internal'),
      '#rows' => 10,
      '#cols' => 60,
      '#resizeable' => 'both',
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
      '#weight' => '20',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = self::configFactory()->getEditable('node_link_report.settings');
    $display_on = $form_state->getValue('allow_display_on');
    $config
      ->set('enable_check_external_links', $form_state->getValue('enable_check_external_links'))
      ->set('enable_reporting_good_links', $form_state->getValue('enable_reporting_good_links'))
      ->set('display_on_node_view', $display_on['node_view'])
      ->set('display_on_node_edit', $display_on['node_edit'])
      ->set('display_on_node_preview', $display_on['node_preview'])
      ->set('additional_domains_as_internal', $form_state->getValue('additional_domains_as_internal'))
      ->save();

    // Since all report displays may have changed due to settings change,
    // invalidate all cache node link reports.
    \Drupal\Core\Cache\Cache::invalidateTags(['node_link_report']);
  }

}
